require "spec_helper"

class PlatformObject
end

describe SpecTest do
  let(:watir_browser) { mock_browser_with_watir }
  let(:selenium_browser) { mock_browser_with_selenium }
  let(:watir_page) { PageTester.new(watir_browser) }
  let(:selenium_page) { PageTester.new(selenium_browser) }

  context "can be included with a page that will be using watir-webdriver" do
    it "which means the page should use a watir platform object" do
      watir_page.platform.should be_kind_of SpecTest::Platforms::WatirWebDriver::PlatformObject
    end
  end

  context "can be included with a page that will be using selenium-webdriver" do
    it "which means the page should use a selenium platform object" do
      selenium_page.platform.should be_kind_of SpecTest::Platforms::SeleniumWebDriver::PlatformObject
    end
  end

  context "might be included with a page using an unrecognized driver" do
    it "and in that case it should raise an exception" do
      expect { PageTester.new("fake_browser") }.to raise_error
    end
  end

  context "might be included with a page using an unassociated custom driver" do
    let(:custom_driver) { mock_driver(:watir_browser, PlatformObject) }
    it "and in that case it should raise an exception" do
      expect { custom_page = PageTester.new(:watir_browser) }.to raise_error
    end
  end

  context "might be included with a page using an associated custom driver" do
    let(:custom_driver) { mock_driver(:custom_browser, PlatformObject) }
    it "which means the page should use a custom platform object" do
      mock_drivers_list({:custom_driver => custom_driver})
      custom_page = PageTester.new(:custom_browser)
      custom_page.platform.should be custom_driver.create_platform_object_for
    end
  end
end