require "spec_helper"

class LoadingPlatforms
  include SpecTest::Platforms
end

describe LoadingPlatforms do
  let(:platform) { LoadingPlatforms.new() }
  let(:drivers) { {} }

  context "if a chrome browser is associated with a chrome platform" do
    let(:chrome_browser) { double('browser') }
    before { drivers[:chrome_browser] = mock_driver(chrome_browser, :chrome_platform) }
    it "then the chrome platform will be established for the chrome browser" do
      platform.platform_for(chrome_browser, drivers).should == :chrome_platform
    end

    context "if a firefox browser is associated with a firefox platform" do
      let(:firefox_browser) { double('browser') }
      before { drivers[:firefox_browser] = mock_driver(firefox_browser, :firefox_platform) }
      it "then the chrome platform will still be established for the chrome platform" do
        platform.platform_for(chrome_browser, drivers).should == :chrome_platform
      end
    end
  end

  context "if a firefox browser is associated with a firefox platform" do
    let(:firefox_browser) { double('browser') }
    before { drivers[:firefox_browser] = mock_driver(firefox_browser, :firefox_platform) }
    it "then the firefox platform will be established for the firefox browser" do
      platform.platform_for(firefox_browser, drivers).should == :firefox_platform
    end
  end

  context "if an unknown browser object is associated with a platform" do
    it "then it should raise an exception" do
      expect { platform.platform_for("false_browser") }.to raise_error
    end
  end
end