require 'simplecov'
SimpleCov.start { add_filter "/spec/" } if ENV['COVERAGE']

require 'rspec'
require 'spectest'

require 'watir-webdriver'
require 'selenium-webdriver'

class PageTester
  include SpecTest
end

RSpec.configure do |config|
  config.color_enabled = true
  config.formatter = 'documentation'
end

def mock_browser_with_watir
  watir_browser = double('watir')
  watir_browser.stub(:is_a?).with(anything()).and_return(false)
  watir_browser.stub(:is_a?).with(Selenium::WebDriver::Driver).and_return(false)
  watir_browser.stub(:is_a?).with(Watir::Browser).and_return(true)
  watir_browser
end

def mock_browser_with_selenium
  selenium_browser = double('selenium')
  selenium_browser.stub(:is_a?).with(anything()).and_return(false)
  selenium_browser.stub(:is_a?).with(Watir::Browser).and_return(false)
  selenium_browser.stub(:is_a?).with(Selenium::WebDriver::Driver).and_return(true)
  selenium_browser
end

def mock_driver(browser, platform_object)
  driver = double('driver')
  driver.stub(:works_for?).with(anything()).and_return(false)
  driver.stub(:works_for?).with(browser).and_return(true)
  driver.stub(:create_platform_object_for).and_return platform_object
  driver
end

def mock_drivers_list(drivers)
  SpecTest::Platforms.stub(:list).and_return drivers
end