require "spec_helper"
require "spectest/web_objects/all"
require "spectest/web_objects/button"

describe SpecTest::WebObjects::Button do
  let(:button) { SpecTest::WebObjects::Button }

  describe "when mapping how to identify a web object" do
    it "it should be able to map watir locators" do
      [:class, :id, :index, :name, :value, :xpath].each do |type|
        locator = button.have_watir_find_object_with type => 'value'
        locator.keys.first.should == type
      end
    end

    it "it should be able to map selenium locators" do
      [:class, :id, :index, :name, :value, :xpath].each do |type|
        key, value = button.have_selenium_find_object_with type => 'value'
        key.should == type
      end
    end
  end

  describe "when performing an action on a web object" do
    let(:button_object) { double('button_object') }

    context "and when selenium is the driver" do
      it "then it should return an error when asked for text" do
        button = SpecTest::WebObjects::Button.new(button_object, :platform => :selenium_webdriver)
        lambda { button.text }.should raise_error
      end
    end
  end

end