require 'spec_helper'
require "spectest/web_objects/all"
require "spectest/web_objects/link"

describe SpecTest::WebObjects::Link do
  let(:link) { SpecTest::WebObjects::Link }

  describe "when mapping how to identify a web object" do
    it "it should be able to map watir locators" do
      [:class, :href, :id, :index, :name, :text, :xpath].each do |type|
        locator = link.have_watir_find_object_with type => 'value'
        locator.keys.first.should == type
      end
    end

    it "it should be able to map selenium locators" do
      [:class, :id, :link, :link_text, :name, :xpath, :index].each do |type|
        key, value = link.have_selenium_find_object_with type => 'value'
        key.should == type
      end
    end

    it "it should be able to map watir selectors to selenium locators" do
      key, value = link.have_selenium_find_object_with :text => 'value'
      key.should == :link_text
    end

    it "it should be able to map selenium selectors to watir locators" do
      [:link, :link_text].each do |type|
        locator = link.have_watir_find_object_with type => 'value'
        locator.keys.first.should == :text
      end
    end
  end

  describe "when performing an action on a web object" do
    let(:link_object) { double('link_object') }

    context "and when selenium is the driver" do
      it "then it should return an error when asked for a value" do
        link = SpecTest::WebObjects::Link.new(link_object, :platform => :selenium_webdriver)
        lambda { link.value }.should raise_error
      end
    end
  end
end
