require "spec_helper"
require "spectest/web_objects/all"
require "spectest/web_objects/text_field"

describe SpecTest::WebObjects::TextField do
  let(:textfield) { SpecTest::WebObjects::TextField }

  describe "when mapping how to identify a web object" do
    it "it should be able to map watir locators" do
      [:class, :id, :index, :name, :tag_name, :xpath].each do |type|
        locator = textfield.have_watir_find_object_with type => 'value'
        locator.keys.first.should == type
      end
    end

    it "it should be able to map selenium locators" do
      [:class, :css, :id, :name, :xpath, :index].each do |type|
        key, value = textfield.have_selenium_find_object_with type => 'value'
        key.should == type
      end
    end

    it "it should be able to map watir selectors to selenium locators" do
      key, value = textfield.have_selenium_find_object_with :tag_name => 'value'
      key.should == :css
    end

    it "it should be able to map selenium selectors to watir locators" do
      locator = textfield.have_watir_find_object_with :css => 'value'
      locator.keys.first.should == :tag_name
    end
  end

  describe "when performing an action on a web object" do
    context "and when selenium is the driver" do
      it "it should be able to set the value of the object" do
        text_field_object = double('selenium_text_field')
        selenium_text_field = SpecTest::WebObjects::TextField.new(text_field_object, :platform => :selenium_webdriver)
        text_field_object.should_receive(:clear)
        text_field_object.should_receive(:send_keys).with('Testing')
        selenium_text_field.value = 'Testing'
      end
    end
  end

end