require 'webrick'

class NonCachingFileHandler < WEBrick::HTTPServlet::FileHandler
  def prevent_caching(res)
    res['ETag']          = nil
    res['Last-Modified'] = Time.now + 100**4
    res['Cache-Control'] = 'no-store, no-cache, must-revalidate, post-check=0, pre-check=0'
    res['Pragma']        = 'no-cache'
    res['Expires']       = Time.now - 100**4
  end
  
  def do_GET(req, res)
    super
    prevent_caching(res)
  end
end

if $0 == __FILE__ then
  server = WEBrick::HTTPServer.new(:Port => 1234, :AccessLog => [])
  server.mount '/', NonCachingFileHandler , './'
  ['INT', 'TERM'].each { |signal|
    trap(signal) { server.stop }
  }
  server.start
end
